@@ -3,12 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(MIDI-Util MIDI-Drummer-Tiny);
 
 use Moo;
-use Carp qw(croak);
 use File::Slurper qw(write_text);
 use MIDI::Util qw(dura_size reverse_dump);
 use File::ShareDir qw(dist_dir);
@@ -193,7 +192,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -424,7 +423,9 @@ written to that file.
   $tabla->play_timidity;
   $tabla->play_timidity($filename);
 
-Play the tabla score with timidity.
+Play the tabla score with timidity. If a B<filename> is given, it is
+used for the timidity configuration. Otherwise a filename of
+C<timidity-tabla.cfg> is used.
 
 =head1 SEE ALSO
 
